import { IAuthenticationProvider, IUserDataSyncResource, IResourcePreview } from "@codingame/monaco-vscode-api/vscode/vs/platform/userDataSync/common/userDataSync";
import { IUserDataAutoSyncService } from "@codingame/monaco-vscode-api/vscode/vs/platform/userDataSync/common/userDataSync.service";
import { IUserDataSyncService } from "@codingame/monaco-vscode-api/vscode/vs/platform/userDataSync/common/userDataSync.service";
import { IUserDataSyncEnablementService } from "@codingame/monaco-vscode-api/vscode/vs/platform/userDataSync/common/userDataSync.service";
import { IUserDataSyncStoreManagementService } from "@codingame/monaco-vscode-api/vscode/vs/platform/userDataSync/common/userDataSync.service";
import { ITelemetryService } from "@codingame/monaco-vscode-api/vscode/vs/platform/telemetry/common/telemetry.service";
import { IUserDataSyncAccount, AccountStatus } from "@codingame/monaco-vscode-api/vscode/vs/workbench/services/userDataSync/common/userDataSync";
import { IUserDataSyncWorkbenchService } from "@codingame/monaco-vscode-api/vscode/vs/workbench/services/userDataSync/common/userDataSync.service";
import { Disposable } from "@codingame/monaco-vscode-api/vscode/vs/base/common/lifecycle";
import { Event } from "@codingame/monaco-vscode-api/vscode/vs/base/common/event";
import { AuthenticationSession } from "@codingame/monaco-vscode-api/vscode/vs/workbench/services/authentication/common/authentication";
import { IAuthenticationService } from "@codingame/monaco-vscode-api/vscode/vs/workbench/services/authentication/common/authentication.service";
import { IUserDataSyncAccountService } from "@codingame/monaco-vscode-api/vscode/vs/platform/userDataSync/common/userDataSyncAccount.service";
import { IQuickInputService } from "@codingame/monaco-vscode-api/vscode/vs/platform/quickinput/common/quickInput.service";
import { IStorageService } from "@codingame/monaco-vscode-api/vscode/vs/platform/storage/common/storage.service";
import { ILogService } from "@codingame/monaco-vscode-api/vscode/vs/platform/log/common/log.service";
import { IProductService } from "@codingame/monaco-vscode-api/vscode/vs/platform/product/common/productService.service";
import { IExtensionService } from "@codingame/monaco-vscode-api/vscode/vs/workbench/services/extensions/common/extensions.service";
import { INotificationService } from "@codingame/monaco-vscode-api/vscode/vs/platform/notification/common/notification.service";
import { IFileDialogService } from "@codingame/monaco-vscode-api/vscode/vs/platform/dialogs/common/dialogs.service";
import { IDialogService } from "@codingame/monaco-vscode-api/vscode/vs/platform/dialogs/common/dialogs.service";
import { IContextKeyService } from "@codingame/monaco-vscode-api/vscode/vs/platform/contextkey/common/contextkey.service";
import { IProgressService } from "@codingame/monaco-vscode-api/vscode/vs/platform/progress/common/progress.service";
import { URI } from "@codingame/monaco-vscode-api/vscode/vs/base/common/uri";
import { IViewDescriptorService } from "@codingame/monaco-vscode-api/vscode/vs/workbench/common/views.service";
import { IViewsService } from "@codingame/monaco-vscode-api/vscode/vs/workbench/services/views/common/viewsService.service";
import { ILifecycleService } from "@codingame/monaco-vscode-api/vscode/vs/workbench/services/lifecycle/common/lifecycle.service";
import { IInstantiationService } from "@codingame/monaco-vscode-api/vscode/vs/platform/instantiation/common/instantiation";
import { IEditorService } from "@codingame/monaco-vscode-api/vscode/vs/workbench/services/editor/common/editorService.service";
import { IUriIdentityService } from "@codingame/monaco-vscode-api/vscode/vs/platform/uriIdentity/common/uriIdentity.service";
import { IBrowserWorkbenchEnvironmentService } from "@codingame/monaco-vscode-411e0589-fa79-504b-b32c-80a88847b23a-common/vscode/vs/workbench/services/environment/browser/environmentService.service";
import { IUserDataInitializationService } from "@codingame/monaco-vscode-api/vscode/vs/workbench/services/userData/browser/userDataInit.service";
import { ISecretStorageService } from "@codingame/monaco-vscode-api/vscode/vs/platform/secrets/common/secrets.service";
import { IFileService } from "@codingame/monaco-vscode-api/vscode/vs/platform/files/common/files.service";
import { IUserDataSyncMachinesService } from "@codingame/monaco-vscode-api/vscode/vs/platform/userDataSync/common/userDataSyncMachines.service";
declare class UserDataSyncAccount implements IUserDataSyncAccount {
    readonly authenticationProviderId: string;
    private readonly session;
    constructor(authenticationProviderId: string, session: AuthenticationSession);
    get sessionId(): string;
    get accountName(): string;
    get accountId(): string;
    get token(): string;
}
type MergeEditorInput = {
    base: URI;
    input1: {
        uri: URI;
    };
    input2: {
        uri: URI;
    };
    result: URI;
};
export declare function isMergeEditorInput(editor: unknown): editor is MergeEditorInput;
export declare class UserDataSyncWorkbenchService extends Disposable implements IUserDataSyncWorkbenchService {
    private readonly userDataSyncService;
    private readonly uriIdentityService;
    private readonly authenticationService;
    private readonly userDataSyncAccountService;
    private readonly quickInputService;
    private readonly storageService;
    private readonly userDataSyncEnablementService;
    private readonly userDataAutoSyncService;
    private readonly telemetryService;
    private readonly logService;
    private readonly productService;
    private readonly extensionService;
    private readonly environmentService;
    private readonly secretStorageService;
    private readonly notificationService;
    private readonly progressService;
    private readonly dialogService;
    private readonly viewsService;
    private readonly viewDescriptorService;
    private readonly userDataSyncStoreManagementService;
    private readonly lifecycleService;
    private readonly instantiationService;
    private readonly editorService;
    private readonly userDataInitializationService;
    private readonly fileService;
    private readonly fileDialogService;
    private readonly userDataSyncMachinesService;
    _serviceBrand: any;
    private static DONOT_USE_WORKBENCH_SESSION_STORAGE_KEY;
    private static CACHED_AUTHENTICATION_PROVIDER_KEY;
    private static CACHED_SESSION_STORAGE_KEY;
    get enabled(): boolean;
    private _authenticationProviders;
    get authenticationProviders(): IAuthenticationProvider[];
    private _accountStatus;
    get accountStatus(): AccountStatus;
    private readonly _onDidChangeAccountStatus;
    readonly onDidChangeAccountStatus: Event<AccountStatus>;
    private readonly _onDidTurnOnSync;
    readonly onDidTurnOnSync: Event<void>;
    private _current;
    get current(): UserDataSyncAccount | undefined;
    private readonly syncEnablementContext;
    private readonly syncStatusContext;
    private readonly accountStatusContext;
    private readonly enableConflictsViewContext;
    private readonly hasConflicts;
    private readonly activityViewsEnablementContext;
    private turnOnSyncCancellationToken;
    constructor(userDataSyncService: IUserDataSyncService, uriIdentityService: IUriIdentityService, authenticationService: IAuthenticationService, userDataSyncAccountService: IUserDataSyncAccountService, quickInputService: IQuickInputService, storageService: IStorageService, userDataSyncEnablementService: IUserDataSyncEnablementService, userDataAutoSyncService: IUserDataAutoSyncService, telemetryService: ITelemetryService, logService: ILogService, productService: IProductService, extensionService: IExtensionService, environmentService: IBrowserWorkbenchEnvironmentService, secretStorageService: ISecretStorageService, notificationService: INotificationService, progressService: IProgressService, dialogService: IDialogService, contextKeyService: IContextKeyService, viewsService: IViewsService, viewDescriptorService: IViewDescriptorService, userDataSyncStoreManagementService: IUserDataSyncStoreManagementService, lifecycleService: ILifecycleService, instantiationService: IInstantiationService, editorService: IEditorService, userDataInitializationService: IUserDataInitializationService, fileService: IFileService, fileDialogService: IFileDialogService, userDataSyncMachinesService: IUserDataSyncMachinesService);
    private updateAuthenticationProviders;
    private isSupportedAuthenticationProviderId;
    private waitAndInitialize;
    private initialize;
    private update;
    private updateCurrentAccount;
    private updateToken;
    private updateAccountStatus;
    turnOn(): Promise<void>;
    turnoff(everywhere: boolean): Promise<void>;
    synchroniseUserDataSyncStoreType(): Promise<void>;
    syncNow(): Promise<void>;
    private doTurnOnSync;
    private handleConflictsWhileTurningOn;
    private replace;
    accept(resource: IUserDataSyncResource, conflictResource: URI, content: string | null | undefined, apply: boolean | {
        force: boolean;
    }): Promise<void>;
    showConflicts(conflictToOpen?: IResourcePreview): Promise<void>;
    resetSyncedData(): Promise<void>;
    getAllLogResources(): Promise<URI[]>;
    showSyncActivity(): Promise<void>;
    downloadSyncActivity(): Promise<URI | undefined>;
    private waitForActiveSyncViews;
    signIn(): Promise<void>;
    private pick;
    private doPick;
    private getAccounts;
    private createQuickpickItems;
    private doSignIn;
    private onDidAuthFailure;
    private onDidChangeSessions;
    private onDidChangeStorage;
    private _cachedCurrentAuthenticationProviderId;
    private get currentAuthenticationProviderId();
    private set currentAuthenticationProviderId(value);
    private _cachedCurrentSessionId;
    private get currentSessionId();
    private set currentSessionId(value);
    private getStoredCachedSessionId;
    private get useWorkbenchSessionId();
    private set useWorkbenchSessionId(value);
}
export {};
